@@ -457,7 +457,7 @@ alva_brl_close_device ()
 
 gint 
 alva_brl_open_device (gchar          *device_name, 
-		      gshort         port, 
+		      gchar          *port, 
 		      BRLDevCallback device_callback,
 		      BRLDevice      *device)
 {
