@@ -1,7 +1,7 @@
 /* srmain.c
  *
- * Copyright 2001, 2002 Sun Microsystems, Inc.,
- * Copyright 2001, 2002 BAUM Retec, A.G.
+ * Copyright 2001 - 2005 Sun Microsystems, Inc.,
+ * Copyright 2001 - 2005 BAUM Retec, A.G.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -45,6 +45,7 @@
 static gboolean src_mouse_is_moving = FALSE;
 static guint mouse_stopped_moving_timeout_handler = 0;
 static guint mouse_is_moving_idle_handler = 0;
+static gint context_switched = 0;
 
 gboolean login_time;
 
@@ -128,7 +129,8 @@ src_present_real_sro_for_brl_and_brlmon (SRObject *obj, gchar *reason)
 	braille_scroll = g_strdup (scroll);
 	
 	sro_get_role (obj, &role, SR_INDEX_CONTAINER);
-	if (role == SR_ROLE_TEXT_SL || role == SR_ROLE_TEXT_ML || role == SR_ROLE_TERMINAL || role == SR_ROLE_COMBO_BOX)
+	if (role == SR_ROLE_TEXT_SL || role == SR_ROLE_TEXT_ML || role == SR_ROLE_TERMINAL 
+	    || role == SR_ROLE_COMBO_BOX || role == SR_ROLE_PASSWORD_TEXT)
 	{
 	    SRLong offset;
 	    SRTextAttribute *attr;
@@ -269,6 +271,9 @@ src_present_real_sro_for_speech (SRObject *obj, gchar *reason)
 	    sro_get_role (obj, &role, SR_INDEX_CONTAINER);
 	    if (srl_is_object_focused (obj) || strcmp (reason, "present") == 0)
 	    {
+		if (context_switched == 1)
+		    src_speech_shutup ();
+		context_switched++;
 		if (role == SR_ROLE_STATUS_BAR && strcmp (reason , "focus:") == 0)
 		    src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
 		else if ((role == SR_ROLE_TABLE || role == SR_ROLE_TREE_TABLE) &&
@@ -402,7 +407,10 @@ src_present_crt_window ()
 	    else if (strcmp (reason, "window:rename") == 0)
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_LOW, TRUE);
 	    else if (strcmp (reason, "object:context-switched") == 0)
-	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_WARNING, TRUE);
+	    {
+		context_switched = 0;
+	    	src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_ERROR, TRUE);
+	    }
 	    else
 		src_speech_send_chunk (txt, SRC_SPEECH_PRIORITY_SYSTEM, TRUE);
 	}
@@ -672,9 +680,11 @@ src_process_config_changed_for_braille (SRConfigStructure *config)
     sru_assert (config->key);
     if (strcmp (config->key, BRAILLE_DEVICE) == 0)
     {
+	gboolean rv;
+
 	sru_assert (config->newvalue && config->type == CFGT_STRING);
 	
-	gboolean rv = src_braille_set_device ((gchar*)config->newvalue);   
+	rv = src_braille_set_device ((gchar*)config->newvalue);   
 	if (!rv)
 	{
 	    sru_message ("SR: process config changed for braille: brl_device did not change!!!");
@@ -682,9 +692,11 @@ src_process_config_changed_for_braille (SRConfigStructure *config)
     }
     else if (strcmp (config->key, BRAILLE_PORT_NO) == 0)
     {
-    	sru_assert (config->newvalue && config->type == CFGT_INT);
-	
-	src_braille_set_port_no (*((gint*)config->newvalue));
+    	src_braille_set_port ();
+    }
+    else if (strcmp (config->key, BRAILLE_PORT) == 0)
+    {
+    	src_braille_set_port ();
     }
     else
 /*    if (config->key && strcmp (config->key, BRAILLE_ATTRIBUTES) == 0)
@@ -706,9 +718,11 @@ src_process_config_changed_for_braille (SRConfigStructure *config)
     }
     else if (strcmp (config->key, BRAILLE_TRANSLATION) == 0)
     {
+	gboolean rv;
+
     	sru_assert (config->type == CFGT_STRING && config->newvalue);
 	
-	gboolean rv = src_braille_set_translation_table ((gchar*)config->newvalue);
+	rv = src_braille_set_translation_table ((gchar*)config->newvalue);
 	
 	if (!rv)
 	{
@@ -1009,7 +1023,7 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf (crosswire ? _("crosshair on") : _("crosshair off"));
+	    tmp = g_strdup_printf (crosswire ? _("crosswire on") : _("crosswire off"));
 	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -1026,8 +1040,8 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf (crosswire_clip ? _("crosshair clip on") :
-				                    _("crosshair clip off"));
+	    tmp = g_strdup_printf (crosswire_clip ? _("crosswire clip on") :
+				                    _("crosswire clip off"));
 	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -1045,7 +1059,7 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf ("%s %d", _("crosshair size"), crosswire_size);
+	    tmp = g_strdup_printf ("%s %d", _("crosswire size"), crosswire_size);
     	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -1063,7 +1077,7 @@ src_process_config_changed_for_magnifier (SRConfigStructure *config)
 	if (rv && src_use_speech)
 	{
 	    gchar *tmp;
-	    tmp = g_strdup_printf ("%s %u", _("crosshair color"), crosswire_color);
+	    tmp = g_strdup_printf ("%s %u", _("crosswire color"), crosswire_color);
     	    src_say_message (tmp);
 	    g_free (tmp);
 	}
@@ -2452,6 +2466,8 @@ src_init(const gchar *mouse_tracking,
     src_last_space_echo 	= NULL;
     src_last_modifier_echo 	= NULL;
     src_last_cursor_echo 	= NULL;
+    context_switched 		= 0;
+
     if (brl_error)
 	src_say_message (_("braille device can not be initialized"));
 
